==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/dm/pmmlagm/apriorigen2.c <==
//  ץǤ
//  ղ Ver.4 
//  '2000/10/03
//
#include "chtree2.c"
#include "mkblock.c"

extern struct trie_node trie[];
extern unsigned long trie_pos;
extern char ltypenum;

void apriorigen2(unsigned long pos1,unsigned long pos2,struct new_node *data)
{
	unsigned long i,j,poin1,poin2,dep,length;
	int k;
	char ans=1;

	dep=trie[pos2].item.size;/*ȤƤΡɤο-1*/
	length=dep*(dep-1)/2;

	for(i=pos1;i<pos2;i++){
		if(trie[i].child!=0){
			for(j=0;j<dep-1;j++)
				data->item.nodetypes[j]=trie[i].item.nodetypes[j];
			for(j=0;j<length-dep+1;j++)
				data->item.code[j]=trie[i].item.code[j];
			for(poin1=trie[i].child;poin1!=0;poin1=trie[poin1].brother){
				for(j=0;j<dep-1;j++)
					data->item.code[length-dep+1+j]=trie[poin1].item.code[length-dep+1+j];
				data->item.size=dep+1;
				data->item.nodetypes[dep-1]=trie[poin1].item.nodetypes[dep-1];
				for(poin2=poin1;poin2!=0;poin2=trie[poin2].brother){
					for(j=0;j<dep-1;j++)
						data->item.code[length+j]=trie[poin2].item.code[length-dep+1+j];	
					data->item.nodetypes[dep]=trie[poin2].item.nodetypes[dep-1];
					if(g_type==2){
						for(k=0;k<ltypenum+1;k++){
							data->item.code[length+dep-1]=(char)k;
							if(dep>1)
								ans=chree2(data,poin1,poin2);
							if(ans!=0)
								mkblock(*data,poin1,poin2);
						}
					}
					else{
						for(k=0;k<(ltypenum+1)*(ltypenum+1);k++){
							data->item.code[length+dep-1]=(char)k;
							ans=chree2(data,poin1,poin2);
							if(ans!=0)
								mkblock(*data,poin1,poin2);
						}
					}
				}
			}
		}
	}
}

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/dm/pmmlagm/apriorigen2.c <==
//  猪口さんが制作したプログラムです。
//  グラフ解析 Ver.4 用
//  '2000/10/03
//
#include "chtree2.c"
#include "mkblock.c"

extern struct trie_node trie[];
extern unsigned long trie_pos;
extern char ltypenum;

void apriorigen2(unsigned long pos1,unsigned long pos2,struct new_node *data)
{
	unsigned long i,j,poin1,poin2,dep,length;
	int k;
	char ans=1;

	dep=trie[pos2].item.size;/*作るろうとしているノードの深さ-1*/
	length=dep*(dep-1)/2;

	for(i=pos1;i<pos2;i++){
		if(trie[i].child!=0){
			for(j=0;j<dep-1;j++)
				data->item.nodetypes[j]=trie[i].item.nodetypes[j];
			for(j=0;j<length-dep+1;j++)
				data->item.code[j]=trie[i].item.code[j];
			for(poin1=trie[i].child;poin1!=0;poin1=trie[poin1].brother){
				for(j=0;j<dep-1;j++)
					data->item.code[length-dep+1+j]=trie[poin1].item.code[length-dep+1+j];
				data->item.size=dep+1;
				data->item.nodetypes[dep-1]=trie[poin1].item.nodetypes[dep-1];
				for(poin2=poin1;poin2!=0;poin2=trie[poin2].brother){
					for(j=0;j<dep-1;j++)
						data->item.code[length+j]=trie[poin2].item.code[length-dep+1+j];	
					data->item.nodetypes[dep]=trie[poin2].item.nodetypes[dep-1];
					if(g_type==2){
						for(k=0;k<ltypenum+1;k++){
							data->item.code[length+dep-1]=(char)k;
							if(dep>1)
								ans=chree2(data,poin1,poin2);
							if(ans!=0)
								mkblock(*data,poin1,poin2);
						}
					}
					else{
						for(k=0;k<(ltypenum+1)*(ltypenum+1);k++){
							data->item.code[length+dep-1]=(char)k;
							ans=chree2(data,poin1,poin2);
							if(ans!=0)
								mkblock(*data,poin1,poin2);
						}
					}
				}
			}
		}
	}
}
